@@ -89,13 +89,13 @@ void usage(char *progname)
 	fprintf(stderr, _("Options are:\n"
 			  "[ -c ] [ -d ] [ -h ] [ -k | -m ] [ -N ] [ -t ] [ -V ] [ -x ] [ -y ] [ -z ]\n"
 			  "[ -j { ID | LABEL | PATH | UUID | ... } ]\n"
-			  "[ [ -T ] -g <group_name> ] [ -p [ <device> [,...] | ALL ] ]\n"
+			  "[ [ -H ] -g <group_name> ] [ -p [ <device> [,...] | ALL ] ]\n"
 			  "[ <device> [...] | ALL ] [ --debuginfo ]\n"));
 #else
 	fprintf(stderr, _("Options are:\n"
 			  "[ -c ] [ -d ] [ -h ] [ -k | -m ] [ -N ] [ -t ] [ -V ] [ -x ] [ -y ] [ -z ]\n"
 			  "[ -j { ID | LABEL | PATH | UUID | ... } ]\n"
-			  "[ [ -T ] -g <group_name> ] [ -p [ <device> [,...] | ALL ] ]\n"
+			  "[ [ -H ] -g <group_name> ] [ -p [ <device> [,...] | ALL ] ]\n"
 			  "[ <device> [...] | ALL ]\n"));
 #endif
 	exit(1);
@@ -1422,6 +1422,11 @@ int main(int argc, char **argv)
 					report_set = TRUE;
 					break;
 
+                                case 'H':
+					/* Display stats only for the groups */
+					flags |= I_D_GROUP_TOTAL_ONLY;
+					break;
+
 				case 'h':
 					/*
 					 * Display device utilization report
@@ -1456,11 +1461,6 @@ int main(int argc, char **argv)
 					flags |= I_D_PARTITIONS + I_D_PART_ALL;
 					break;
 
-				case 'T':
-					/* Display stats only for the groups */
-					flags |= I_D_GROUP_TOTAL_ONLY;
-					break;
-
 				case 't':
 					/* Display timestamp */
 					flags |= I_D_TIMESTAMP;
@@ -1496,7 +1496,7 @@ int main(int argc, char **argv)
 		else if (!isdigit(argv[opt][0])) {
 			/*
 			 * By default iostat doesn't display unused devices.
-			 * If some devices are explictly entered on the command line
+			 * If some devices are explicitly entered on the command line
 			 * then don't apply this rule any more.
 			 */
 			flags |= I_D_UNFILTERED;
